[![Python 3.11+](https://img.shields.io/badge/python-3.11+-blue.svg)]()

<!-- [![tests](https://github.com/Future-House/llm-client/actions/workflows/test.yaml/badge.svg)](https://github.com/Future-House/llm-client) -->

[![PyPI version](https://badge.fury.io/py/fh-llm-client.svg)](https://badge.fury.io/py/fh-llm-client)

# llm-client

Central FutureHouse LLM client library.

## Quick Start

```
$ pip install -e .
$ uv sync && uv run pytest -n auto
```

## Clients

- LLMModel
- LLMResult

## Examples

- [PaperQA](https://github.com/Future-House/paper-qa/compare/main...llm-result-client)
- [LDP](https://github.com/Future-House/ldp/compare/main...llm-result-client)
